==> application-blocks-security-4.3-sources.jar: org/genesys/blocks/oauth/model/Authorization.java <==
/*
 * Copyright 2023 Global Crop Diversity Trust
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.genesys.blocks.oauth.model;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.time.Instant;

@Entity
@Table(name = "oauth_authorization")
public class Authorization {
	
	@Id
	@Column(name = "oauth_authorization_id")
	private String id;

	@Column(name = "registered_client_id", columnDefinition = "int")
	private Long registeredClientId;
	
	@Column(name = "principal_name")
	private String principalName;

	@Column(name = "authorization_grant_type")
	private String authorizationGrantType;
	
	@Column
	private String attributes;
	
	@Column(length = 50)
	private String state;

	@Column(name = "authorization_code_value")
	private String authorizationCodeValue;

	@Column(name = "authorization_code_issued_at")
	private Instant authorizationCodeIssuedAt;

	@Column(name = "authorization_code_expires_at")
	private Instant authorizationCodeExpiresAt;

	@Column(name = "authorization_code_metadata")
	private String authorizationCodeMetadata;
	
	@Column(name = "access_token_id")
	private String accessTokenId;

	@Column(name = "access_token_issued_at")
	private Instant accessTokenIssuedAt;

	@Column(name = "access_token_expires_at")
	private Instant accessTokenExpiresAt;
	
	@Column(name = "access_token_metadata")
	private String accessTokenMetadata;

	@Column(name = "access_token_type")
	private String accessTokenType;
	
	@Column(length = 100, name = "access_token_scopes")
	private String accessTokenScopes;

	@Column(name = "refresh_token_id")
	private String refreshTokenId;

	@Column(name = "refresh_token_issued_at")
	private Instant refreshTokenIssuedAt;

	@Column(name = "refresh_token_expires_at")
	private Instant refreshTokenExpiresAt;

	@Column(name = "refresh_token_metadata")
	private String refreshTokenMetadata;

	@Column(name = "oidc_id_token_id")
	private String oidcIdTokenId;

	@Column(name = "oidc_id_token_issued_at")
	private Instant oidcIdTokenIssuedAt;

	@Column(name = "oidc_id_token_expires_at")
	private Instant oidcIdTokenExpiresAt;

	@Column(name = "oidc_id_token_metadata")
	private String oidcIdTokenMetadata;

	@Column(name = "oidc_id_token_claims")
	private String oidcIdTokenClaims;

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public Long getRegisteredClientId() {
		return registeredClientId;
	}

	public void setRegisteredClientId(Long registeredClientId) {
		this.registeredClientId = registeredClientId;
	}

	public String getPrincipalName() {
		return principalName;
	}

	public void setPrincipalName(String principalName) {
		this.principalName = principalName;
	}

	public String getAuthorizationGrantType() {
		return authorizationGrantType;
	}

	public void setAuthorizationGrantType(String authorizationGrantType) {
		this.authorizationGrantType = authorizationGrantType;
	}

	public String getAttributes() {
		return attributes;
	}

	public void setAttributes(String attributes) {
		this.attributes = attributes;
	}

	public String getState() {
		return state;
	}

	public void setState(String state) {
		this.state = state;
	}

	public String getAuthorizationCodeValue() {
		return authorizationCodeValue;
	}

	public void setAuthorizationCodeValue(String authorizationCodeValue) {
		this.authorizationCodeValue = authorizationCodeValue;
	}

	public Instant getAuthorizationCodeIssuedAt() {
		return authorizationCodeIssuedAt;
	}

	public void setAuthorizationCodeIssuedAt(Instant authorizationCodeIssuedAt) {
		this.authorizationCodeIssuedAt = authorizationCodeIssuedAt;
	}

	public Instant getAuthorizationCodeExpiresAt() {
		return authorizationCodeExpiresAt;
	}

	public void setAuthorizationCodeExpiresAt(Instant authorizationCodeExpiresAt) {
		this.authorizationCodeExpiresAt = authorizationCodeExpiresAt;
	}

	public String getAuthorizationCodeMetadata() {
		return authorizationCodeMetadata;
	}

	public void setAuthorizationCodeMetadata(String authorizationCodeMetadata) {
		this.authorizationCodeMetadata = authorizationCodeMetadata;
	}

	public String getAccessTokenId() {
		return accessTokenId;
	}

	public void setAccessTokenId(String accessTokenId) {
		this.accessTokenId = accessTokenId;
	}

	public Instant getAccessTokenIssuedAt() {
		return accessTokenIssuedAt;
	}

	public void setAccessTokenIssuedAt(Instant accessTokenIssuedAt) {
		this.accessTokenIssuedAt = accessTokenIssuedAt;
	}

	public Instant getAccessTokenExpiresAt() {
		return accessTokenExpiresAt;
	}

	public void setAccessTokenExpiresAt(Instant accessTokenExpiresAt) {
		this.accessTokenExpiresAt = accessTokenExpiresAt;
	}

	public String getAccessTokenMetadata() {
		return accessTokenMetadata;
	}

	public void setAccessTokenMetadata(String accessTokenMetadata) {
		this.accessTokenMetadata = accessTokenMetadata;
	}

	public String getAccessTokenType() {
		return accessTokenType;
	}

	public void setAccessTokenType(String accessTokenType) {
		this.accessTokenType = accessTokenType;
	}

	public String getAccessTokenScopes() {
		return accessTokenScopes;
	}

	public void setAccessTokenScopes(String accessTokenScopes) {
		this.accessTokenScopes = accessTokenScopes;
	}

	public String getRefreshTokenId() {
		return refreshTokenId;
	}

	public void setRefreshTokenId(String refreshTokenId) {
		this.refreshTokenId = refreshTokenId;
	}

	public Instant getRefreshTokenIssuedAt() {
		return refreshTokenIssuedAt;
	}

	public void setRefreshTokenIssuedAt(Instant refreshTokenIssuedAt) {
		this.refreshTokenIssuedAt = refreshTokenIssuedAt;
	}

	public Instant getRefreshTokenExpiresAt() {
		return refreshTokenExpiresAt;
	}

	public void setRefreshTokenExpiresAt(Instant refreshTokenExpiresAt) {
		this.refreshTokenExpiresAt = refreshTokenExpiresAt;
	}

	public String getRefreshTokenMetadata() {
		return refreshTokenMetadata;
	}

	public void setRefreshTokenMetadata(String refreshTokenMetadata) {
		this.refreshTokenMetadata = refreshTokenMetadata;
	}

	public String getOidcIdTokenId() {
		return oidcIdTokenId;
	}

	public void setOidcIdTokenId(String oidcIdTokenId) {
		this.oidcIdTokenId = oidcIdTokenId;
	}

	public Instant getOidcIdTokenIssuedAt() {
		return oidcIdTokenIssuedAt;
	}

	public void setOidcIdTokenIssuedAt(Instant oidcIdTokenIssuedAt) {
		this.oidcIdTokenIssuedAt = oidcIdTokenIssuedAt;
	}

	public Instant getOidcIdTokenExpiresAt() {
		return oidcIdTokenExpiresAt;
	}

	public void setOidcIdTokenExpiresAt(Instant oidcIdTokenExpiresAt) {
		this.oidcIdTokenExpiresAt = oidcIdTokenExpiresAt;
	}

	public String getOidcIdTokenMetadata() {
		return oidcIdTokenMetadata;
	}

	public void setOidcIdTokenMetadata(String oidcIdTokenMetadata) {
		this.oidcIdTokenMetadata = oidcIdTokenMetadata;
	}

	public String getOidcIdTokenClaims() {
		return oidcIdTokenClaims;
	}

	public void setOidcIdTokenClaims(String oidcIdTokenClaims) {
		this.oidcIdTokenClaims = oidcIdTokenClaims;
	}

	@Override
	public String toString() {
		return "Authorization{" +
			"id='" + id + '\'' +
			", registeredClientId='" + registeredClientId + '\'' +
			", principalName='" + principalName + '\'' +
			", authorizationGrantType='" + authorizationGrantType + '\'' +
			", attributes='" + attributes + '\'' +
			", state='" + state + '\'' +
			", authorizationCodeValue='" + authorizationCodeValue + '\'' +
			", authorizationCodeIssuedAt=" + authorizationCodeIssuedAt +
			", authorizationCodeExpiresAt=" + authorizationCodeExpiresAt +
			", authorizationCodeMetadata='" + authorizationCodeMetadata + '\'' +
			", accessTokenId='" + accessTokenId + '\'' +
			", accessTokenIssuedAt=" + accessTokenIssuedAt +
			", accessTokenExpiresAt=" + accessTokenExpiresAt +
			", accessTokenMetadata='" + accessTokenMetadata + '\'' +
			", accessTokenType='" + accessTokenType + '\'' +
			", accessTokenScopes='" + accessTokenScopes + '\'' +
			", refreshTokenId='" + refreshTokenId + '\'' +
			", refreshTokenIssuedAt=" + refreshTokenIssuedAt +
			", refreshTokenExpiresAt=" + refreshTokenExpiresAt +
			", refreshTokenMetadata='" + refreshTokenMetadata + '\'' +
			", oidcIdTokenId='" + oidcIdTokenId + '\'' +
			", oidcIdTokenIssuedAt=" + oidcIdTokenIssuedAt +
			", oidcIdTokenExpiresAt=" + oidcIdTokenExpiresAt +
			", oidcIdTokenMetadata='" + oidcIdTokenMetadata + '\'' +
			", oidcIdTokenClaims='" + oidcIdTokenClaims + '\'' +
			'}';
	}
}

==> application-blocks-security-5.2-sources.jar: org/genesys/blocks/oauth/model/Authorization.java <==
/*
 * Copyright 2023 Global Crop Diversity Trust
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.genesys.blocks.oauth.model;

import lombok.Data;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.time.Instant;

@Entity
@Table(name = "oauth_authorization")
@Data
public class Authorization {
	
	@Id
	@Column(name = "oauth_authorization_id")
	private String id;

	@Column(name = "registered_client_id", columnDefinition = "int")
	private Long registeredClientId;
	
	@Column(name = "principal_name")
	private String principalName;

	@Column(name = "authorization_grant_type")
	private String authorizationGrantType;
	
	@Column
	private String attributes;
	
	@Column(length = 50)
	private String state;

	@Column(name = "authorization_code_value")
	private String authorizationCodeValue;

	@Column(name = "authorization_code_issued_at")
	private Instant authorizationCodeIssuedAt;

	@Column(name = "authorization_code_expires_at")
	private Instant authorizationCodeExpiresAt;

	@Column(name = "authorization_code_metadata")
	private String authorizationCodeMetadata;
	
	@Column(name = "access_token_id")
	private String accessTokenId;

	@Column(name = "access_token_issued_at")
	private Instant accessTokenIssuedAt;

	@Column(name = "access_token_expires_at")
	private Instant accessTokenExpiresAt;
	
	@Column(name = "access_token_metadata")
	private String accessTokenMetadata;

	@Column(name = "access_token_type")
	private String accessTokenType;
	
	@Column(length = 100, name = "access_token_scopes")
	private String accessTokenScopes;

	@Column(name = "refresh_token_id")
	private String refreshTokenId;

	@Column(name = "refresh_token_issued_at")
	private Instant refreshTokenIssuedAt;

	@Column(name = "refresh_token_expires_at")
	private Instant refreshTokenExpiresAt;

	@Column(name = "refresh_token_metadata")
	private String refreshTokenMetadata;

	@Column(name = "oidc_id_token_id")
	private String oidcIdTokenId;

	@Column(name = "oidc_id_token_issued_at")
	private Instant oidcIdTokenIssuedAt;

	@Column(name = "oidc_id_token_expires_at")
	private Instant oidcIdTokenExpiresAt;

	@Column(name = "oidc_id_token_metadata")
	private String oidcIdTokenMetadata;

	@Column(name = "oidc_id_token_claims")
	private String oidcIdTokenClaims;
	
	@Override
	public String toString() {
		return "Authorization{" +
			"id='" + id + '\'' +
			", registeredClientId='" + registeredClientId + '\'' +
			", principalName='" + principalName + '\'' +
			", authorizationGrantType='" + authorizationGrantType + '\'' +
			", attributes='" + attributes + '\'' +
			", state='" + state + '\'' +
			", authorizationCodeValue='" + authorizationCodeValue + '\'' +
			", authorizationCodeIssuedAt=" + authorizationCodeIssuedAt +
			", authorizationCodeExpiresAt=" + authorizationCodeExpiresAt +
			", authorizationCodeMetadata='" + authorizationCodeMetadata + '\'' +
			", accessTokenId='" + accessTokenId + '\'' +
			", accessTokenIssuedAt=" + accessTokenIssuedAt +
			", accessTokenExpiresAt=" + accessTokenExpiresAt +
			", accessTokenMetadata='" + accessTokenMetadata + '\'' +
			", accessTokenType='" + accessTokenType + '\'' +
			", accessTokenScopes='" + accessTokenScopes + '\'' +
			", refreshTokenId='" + refreshTokenId + '\'' +
			", refreshTokenIssuedAt=" + refreshTokenIssuedAt +
			", refreshTokenExpiresAt=" + refreshTokenExpiresAt +
			", refreshTokenMetadata='" + refreshTokenMetadata + '\'' +
			", oidcIdTokenId='" + oidcIdTokenId + '\'' +
			", oidcIdTokenIssuedAt=" + oidcIdTokenIssuedAt +
			", oidcIdTokenExpiresAt=" + oidcIdTokenExpiresAt +
			", oidcIdTokenMetadata='" + oidcIdTokenMetadata + '\'' +
			", oidcIdTokenClaims='" + oidcIdTokenClaims + '\'' +
			'}';
	}
}
